/*
The contents of this file are subject to the Mozilla Public
License Version 1.1 (the "License"); you may not use this file
except in compliance with the License. You may obtain a copy of
the License at http://www.mozilla.org/MPL/

Software distributed under the License is distributed on an "AS
IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
implied. See the License for the specific language governing
rights and limitations under the License.

Alternatively, the contents of this file may be used under the
terms of the GNU General Public License Version 2 or later (the
"GPL"), in which case the provisions of the GPL are applicable 
instead of those above.

Copyright (C) 2002 Tomas Styblo <tripie@cpan.org>
Copyright (C) 2006 Vladimir Marek <vlmarek@volny.cz>
*/

/*
How to add new preference
=========================

a) Add the name to the prefs hash below. Let's say "new.config.var" : "Char".
   Available types are Bool, Char and Int.
b) At pref-mozex.xul add corresponding UI element. It's ID _must be_
   prefMozexNewConfigVar
c) To obtain preference value in mozex.js or elsewhere, just call
   mozexReadPref("new.config.var");
*/

var prefs =
{
    "debug.exec"           : "Bool" , 
    "intercept.mailto"     : "Bool" , 
    "intercept.news"       : "Bool" , 
    "intercept.telnet"     : "Bool" , 
    "intercept.ftp"        : "Bool" , 
    "intercept.irc"        : "Bool" , 
    "general.tmpdir"       : "Char" , 
    "command.mailer"       : "Char" , 
    "command.source"       : "Char" , 
    "command.textarea"     : "Char" , 
    "command.textarea.utf" : "Bool" , 
    "command.textarea.unwrap" : "Bool" , 
    "command.textarea.disable.keyedit" : "Bool" ,
    "command.news"         : "Char" , 
    "command.telnet"       : "Char" , 
    "command.ftp"          : "Char" , 
    "command.irc"          : "Char" , 
    "command.download"     : "Char" , 
    "command.ed2k"         : "Char" , 
    "command.aim"          : "Char" , 
    "universal.schemes"    : "Char" , 
    "universal.command"    : "Char"
}

var mozex_prefs = Components.classes["@mozilla.org/preferences-service;1"].
    getService(Components.interfaces.nsIPrefService).getBranch("mozex.");

function mozexReadPref(name) {
    if (mozex_prefs.prefHasUserValue(name)) {
        var type = mozex_prefs.getPrefType(name);
        if (type & 128) {
            return mozex_prefs.getBoolPref(name);
        }
        else if (type & 64) {
            return mozex_prefs.getIntPref(name);
        }
        else if (type & 32) {
            return mozex_prefs.getCharPref(name);
        }
        else {
            return null;
        }
    }
    else {
        return null;
    }
}

function name2id(name)
{
    /* "command.editor" -> "prefMozexCommandEditor" */

    var id="prefMozex";
    var array=name.split(/\./);
    for (var atom in array)
    {
        id+=array[atom].slice(0,1).toUpperCase();
        id+=array[atom].slice(1);
    }
    return id;
}

function initMozexPref()
{
    var error_message="";
    for (var x in prefs)
    {
        try
        {
            var id=name2id(x);
            var access = (prefs[x] == "Bool") ? "checked" : "value";
            document.getElementById(id)[access] = mozexReadPref(x);
        }  catch (e) {
            error_message+=e+" id='"+id+"'\n";
        }
    }
    if(error_message.length>0)
    {
        alert("initMozexPref:\n"+error_message);
    }
}

function initMozexPrefPanel()
{
    initMozexPref();
}

function changeMozexPrefs()
{
    var error_message="";
    for (var x in prefs)
    {
        try
        {
            var id=name2id(x);
            var access = (prefs[x] == "Bool") ? "checked" : "value";
            mozex_prefs["set"+prefs[x]+"Pref"](x, document.getElementById(id)[access]);
        }  catch (e) {
            error_message+=e+" id='"+id+"'\n";
        }
    }
    if(error_message.length>0)
    {
        alert("changeMozexPrefs:\n"+error_message);
    }
}

/*
vim: tabstop=4:shiftwidth=4:expandtab:cindent
*/
